<?php
include_once('defines.php');

class EventFatory
{
  var $dir;
  var $ev;
  var $name;
  var $desc;
  var $date;
  var $pass;
  var $hwKey;
  var $lang;
  var $thash;

  function __construct()
  {
    $this->dir = '';
    $this->ev = '';
    $this->name = '';
    $this->desc = '';
    $this->date = '';
    $this->pass = '';
    $this->hwKey = 0;
    $this->lang = '';

    $args = func_get_args();

    if (count($args) == 2)
    { //$dir, $epath
      $this->dir = $args[0];
      $this->ev = $args[1];
      $this->date = '2000-01-01';
    }

    if (count($args) == 7)
    { //$dir, $ecode, $ename, $edesc, $epass, $hw, $lang
      $this->dir = $args[0];
      if (strlen($args[1]) >= 1 && is_numeric($args[5]) && (0+$args[5]) > 0)
        $this->ev = substr(sha1($args[1].":".$args[5]), 0, 16);
      $this->name = hex2bin($args[2]);
      $this->desc = hex2bin($args[3]);
      if (strlen($args[1]) > 10 && $args[1][4] == '-' && $args[1][7] == '-')
        $this->date = substr($args[1],0,10);
      $this->pass = $args[4];
      if (is_numeric($args[5]))
        $this->hwKey = 0+$args[5];
      $this->lang = $args[6];
    }
  }

  function isValid()
  {
    return ($this->ev != NULL) && (strlen($this->date) > 0);
  }

  function getHwKey()
  {
    return $this->hwKey;
  }

  function getPath()
  {
    return $this->ev;
  }

  function getTitleHash()
  {
    return $this->thash;
  }

  function getIndexPath()
  {
    return 'events/'.($this->ev)."/index.php";
  }

  function getMailScratchPath()
  {
    return 'events/'.($this->ev)."/mails-to-send.txt";
  }

  function getUploadScriptPath()
  {
    return 'events/'.($this->ev)."/upload-preview.sh";
  }

  function eventDirExists()
  {
    return $this->getIndexPath() && file_exists(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/originals')
             && file_exists(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/lpreviews')
             && file_exists(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/mpreviews')
             && file_exists(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/hpreviews')
             && file_exists(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/title');
  }

  function makeEventIndex()
  {
    if (file_exists($this->getIndexPath()))
      unlink($this->getIndexPath());
    $indexContent = "<?php\n";
    if (strlen($this->pass) > 0)
      $indexContent .= '$password = \''.$this->pass."';\n";
    $indexContent .= '$cdir = \''.$this->dir."';\n";
    $indexContent .= "\n";
    $indexContent .= file_get_contents('event-index.tmpl');
    return file_put_contents($this->getIndexPath(), $indexContent);
  }

  function prepareEvent()
  {
    if (!mkdir('events/'.$this->ev))
      return false;
    if (!mkdir(FOTO_STORAGE.$this->dir.'/'.$this->ev))
      return false;
    if (!mkdir(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/originals'))
      return false;
    if (!mkdir(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/lpreviews'))
      return false;
    if (!mkdir(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/mpreviews'))
      return false;
    if (!mkdir(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/hpreviews'))
      return false;
    if (!mkdir(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/gifs'))
      return false;
    if (!mkdir(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/title'))
      return false;
    if (!copy('title-default.jpg', FOTO_STORAGE.$this->dir.'/'.$this->ev.TITLE_PATH))
      return false;
    if (!($this->makeEventIndex()))
      return false;
    return true;
  }

  function makeTitleHash()
  {
    $this->thash = substr(sha1_file(FOTO_STORAGE.$this->dir.'/'.$this->ev.TITLE_PATH), 0, 8);
    return true;
  }

  function mineEventPass()
  {
    if (!file_exists($this->getIndexPath()))
      return FALSE;
    $indexContent = file_get_contents($this->getIndexPath(), false, NULL, 5, 50);
    $rv = strstr($indexContent, '$password = \'');
    if (strlen($rv) < 13)
      return '';
    return strstr(substr($rv,13), '\';', true);
  }

  function saveMailReq($emails, $prints)
  {
    if (count($emails) < 1 || count($prints) < 1)
      return FALSE;

    $content = '';
    foreach ($emails as $email)
      $content .= $email.' '.implode(' ', $prints)."\n";
    
    return file_put_contents($this->getMailScratchPath(), $content, FILE_APPEND | LOCK_EX);
  }

  function updateTitle($db, $tFile, $tHash)
  {
    if (!move_uploaded_file($tFile, FOTO_STORAGE.$this->dir.'/'.$this->ev.TITLE_PATH))
      return FALSE;
    return $db->updateTitle($this->ev, $tHash);
  }

  function insertOriginal($tFile, $iName)
  {
    if (!move_uploaded_file($tFile, FOTO_STORAGE.$this->dir.'/'.$this->ev.'/originals/'.$iName.'.jpg'))
      return FALSE;
    return TRUE;
  }

  function insertGif($tFile, $iName)
  {
    if (!move_uploaded_file($tFile, FOTO_STORAGE.$this->dir.'/'.$this->ev.'/gifs/'.$iName.'.gif'))
      return FALSE;
    return TRUE;
  }

  function makePreviews($iName)
  {
    $cmd = PREV_RESIZER.' '.FOTO_STORAGE.$this->dir.'/'.$this->ev.' '.$iName.'.jpg';
    exec($cmd, $output,$retval);
    return ($retval == 0);
  }

  function uploadPreview($iName)
  {
    $script = $this->getUploadScriptPath();
    if (!file_exists($script))
	return true; //nothing to do
    $cmd = $script.' '.$iName;
    exec($cmd, $output, $retval);
    return ($retval == 0);
  }

  function deleteFoto($photo)
  {
    return unlink(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/originals/'.$photo.'.jpg')
        && unlink(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/lpreviews/'.$photo.'.jpg')
        && unlink(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/mpreviews/'.$photo.'.jpg')
        && unlink(FOTO_STORAGE.$this->dir.'/'.$this->ev.'/hpreviews/'.$photo.'.jpg');
  }

  function updateDb($db,$domain,$branch)
  {
    $this->makeTitleHash();
    $pub = strlen($this->pass) < 1 ? 1 : 0;

    return $db->insertOrUpdate($this->ev,$domain,$this->name, $this->desc,$branch,$pub,$this->lang,$this->thash,$this->date);
  }
}


